@@ -10,6 +10,17 @@ PPIx::Regexp - Represent a regular expression of some sort
  PPIx::Regexp::Dumper->new( $re )
      ->print();
 
+=head1 DEPRECATION NOTICE
+
+The L<postderef|/postderef Boolean> argument to L<new()|/new> is being
+put through a deprecation cycle and retracted. After the retraction,
+postfix dereferences will always be recognized. This is the default
+behaviour now.
+
+Starting with the first release after October 1 2020, the first use of
+this argument will warn. Six months after that all uses will warn. After
+a further six months, all uses will become fatal.
+
 =head1 INHERITANCE
 
 C<PPIx::Regexp> is a L<PPIx::Regexp::Node|PPIx::Regexp::Node>.
@@ -60,7 +71,7 @@ experiment that I consider failed. Therefore this use is B<deprecated>
 in favor of L<PPIx::QuoteLike|PPIx::QuoteLike>. As of version 0.058_01,
 the first use of the C<parse> argument to L<new()|/new> resulted in a
 warning. As of version 0.062_01, all uses of the C<parse> argument
-resulted in a warning. After another six months, the C<parse> argument
+resulted in a warning. As of version 0.068_01, the C<parse> argument
 will become fatal.
 
 The author will attempt to preserve the documented interface, but if the
@@ -163,15 +174,27 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Node };
 
-use PPIx::Regexp::Constant qw{ @CARP_NOT };
+use Carp;
+use PPIx::Regexp::Constant qw{
+    ARRAY_REF
+    LOCATION_LINE
+    LOCATION_CHARACTER
+    LOCATION_COLUMN
+    LOCATION_LOGICAL_LINE
+    LOCATION_LOGICAL_FILE
+    @CARP_NOT
+};
 use PPIx::Regexp::Lexer ();
-use PPIx::Regexp::StringTokenizer;
 use PPIx::Regexp::Token::Modifier ();	# For its modifier manipulations.
 use PPIx::Regexp::Tokenizer;
-use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
+use PPIx::Regexp::Util qw{
+    __choose_tokenizer_class
+    __instance
+};
 use Scalar::Util qw{ refaddr };
+use Text::Tabs ();
 
-our $VERSION = '0.067';
+our $VERSION = '0.071';
 
 =head2 new
 
@@ -227,6 +250,28 @@ string before it tokenizes it. For example:
      encoding => 'iso-8859-1',
  );
 
+=item index_locations Boolean
+
+This Boolean option specifies whether the locations of the elements in
+the regular expression should be indexed.
+
+If unspecified or specified as C<undef> a default value is used. This
+default is true if the argument is a L<PPI::Element|PPI::Element> or the
+C<location> option was specified. Otherwise the default is false.
+
+=item location array_reference
+
+This option specifies the location of the new object in the document
+from which it was created. It is a reference to a five-element array
+compatible with that returned by the C<location()> method of
+L<PPI::Element|PPI::Element>.
+
+If not specified, the location of the original string is used if it was
+specified as a L<PPI::Element|PPI::Element>.
+
+If no location can be determined, the various C<location()> methods will
+return C<undef>.
+
 =item parse parse_type
 
 This option specifies what kind of parse is to be done. Possible values
@@ -236,37 +281,13 @@ experimental.
 As it turns out, I consider parsing non-regexp quote-like things with
 this class to be a failed experiment, and the relevant functionality is
 being deprecated and removed in favor of
-L<PPIx::QuoteLike|PPIx::QuoteLike>. See above for details.
+L<PPIx::QuoteLike|PPIx::QuoteLike>. See above for details. As of version
+0.068_01, any use of this option throws an exception.
 
-If C<'regex'> is specified, the first argument is expected to be a valid
-regex, and parsed as though it were.
+=item postderef Boolean
 
-If C<'string'> is specified, the first argument is expected to be a
-valid string literal and parsed as such. The return is still a
-C<PPIx::Regexp> object, but the
-L<regular_expression()|/regular_expression> and L<modifier()|/modifier>
-methods return nothing, and the L<replacement()|/replacement> method
-returns the content of the string.
-
-If C<'guess'> is specified, this method will try to guess what the first
-argument is. If the first argument is a L<PPI::Element|PPI::Element>,
-the guess will reflect the PPI parse. But the guess can be wrong if the
-first argument is a string representing an unusually-delimited regex.
-For example, C<'guess'> will parse C<"foo"> as a string, but Perl will
-parse it as a regex if preceded by a regex binding operator (e.g. C<$x
-=~ "foo">), as shown by
-
- perl -MO=Deparse -e '$x =~ "foo"'
-
-which prints
-
- $x =~ /foo/u
-
-under Perl 5.22.0.
-
-The default is C<'regex'>.
-
-=item postderef boolean
+B<THIS ARGUMENT IS DEPRECATED>.
+See L<DEPRECATION NOTICE|/DEPRECATION NOTICE> above for the details.
 
 This option is passed on to the tokenizer, where it specifies whether
 postfix dereferences are recognized in interpolations and code. This
@@ -284,7 +305,7 @@ Note that if L<PPI|PPI> starts unconditionally recognizing postfix
 dereferences, this argument will immediately become ignored, and will be
 put through a deprecation cycle and removed.
 
-=item strict boolean
+=item strict Boolean
 
 This option is passed on to the tokenizer and lexer, where it specifies
 whether the parse should assume C<use re 'strict'> is in effect.
@@ -326,15 +347,16 @@ is it supported.
 	my ( $class, $content, %args ) = @_;
 	ref $class and $class = ref $class;
 
+	# We have to do this very early so the tokenizer can see it.
+	defined $args{index_locations}
+	    or $args{index_locations} = (
+	    !! $args{location} || __instance( $content, 'PPI::Element' ) );
+
 	$errstr = undef;
 
-	my $tokenizer_class = __choose_tokenizer_class( $content, \%args )
-	    or do {
-	    $errstr = ref $content ?
-		sprintf '%s not supported', ref $content :
-		"Unknown parse type '$args{parse}'";
-	    return;
-	};
+	# As of 0.068_01 this either fails or returns
+	# PPIx::Regexp::Tokenizer
+	my $tokenizer_class = __choose_tokenizer_class( $content, \%args );
 
 	my $tokenizer = $tokenizer_class->new(
 	    $content, %args ) or do {
@@ -345,10 +367,20 @@ is it supported.
 	my $lexer = PPIx::Regexp::Lexer->new( $tokenizer, %args );
 	my @nodes = $lexer->lex();
 	my $self = $class->SUPER::__new( @nodes );
+	$self->{index_locations} = $args{index_locations};
 	$self->{source} = $content;
 	$self->{failures} = $lexer->failures();
 	$self->{effective_modifiers} =
 	    $tokenizer->__effective_modifiers();
+	if ( $args{location} ) {
+	    ARRAY_REF eq ref $args{location}
+		or croak q<Argument 'location' must be an array reference>;
+	    foreach my $inx ( 0 .. 3 ) {
+		$args{location}[$inx] =~ m/ [^0-9] /smx
+		    and croak "Argument 'location' element $inx must be an unsigned integer";
+	    }
+	    $self->{location} = $args{location};
+	}
 	return $self;
     }
 
@@ -652,7 +684,7 @@ sub modifier_asserted {
 # This is a kluge for both determining whether the object asserts
 # modifiers (hence the 'ductype') and determining whether the given
 # modifier is actually asserted. The signature is the invocant and the
-# modifier name, which must not be undef. The return is a boolean.
+# modifier name, which must not be undef. The return is a Boolean.
 *__ducktype_modifier_asserted = \&modifier_asserted;
 
 # As of Perl 5.21.1 you can not leave off the type of a '?'-delimited
@@ -772,7 +804,7 @@ guess. That is, it employs various heuristics on the code to try to
 figure out what the programmer wanted. These heuristics are documented
 as being undocumented (!) and subject to change without notice. As an
 example of the problems even F<perl> faces in parsing Perl, see
-L<https://rt.perl.org/Public/Bug/Display.html?id=133027>.
+L<https://github.com/perl/perl5/issues/16478>.
 
 Given this situation, this module's chances of duplicating every Perl
 version's interpretation of every regular expression are pretty much nil.
@@ -908,7 +940,7 @@ is again supported.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -916,7 +948,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2019 by Thomas R. Wyant, III
+Copyright (C) 2009-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
