@@ -44,7 +44,7 @@ use PPIx::Regexp::Constant qw{
     @CARP_NOT
 };
 
-our $VERSION = '0.068';
+our $VERSION = '0.071';
 
 use constant VERSION_WHEN_IN_REGEX_SET => '5.017009';
 
@@ -59,6 +59,15 @@ sub __new {
     return $self;
 }
 
+=head2 is_matcher
+
+This method returns C<undef> because a static analysis can not in
+general tell whether a piece of code matches anything.
+
+=cut
+
+sub is_matcher { return undef; }	## no critic (ProhibitExplicitReturnUndef)
+
 # Return true if the token can be quantified, and false otherwise
 # This can be quantified because it might interpolate a quantifiable
 # token. Of course, it might not, but we need to be permissive here.
@@ -74,36 +83,27 @@ sub perl_version_introduced {
     return $self->{perl_version_introduced};
 }
 
-=head2 ppi
-
-This convenience method returns the L<PPI::Document|PPI::Document>
-representing the content. This document should be considered read only.
-
-Note that the content of the returned L<PPI::Document|PPI::Document> may
-not be the same as the content of the original
-C<PPIx::Regexp::Token::Interpolation>. This can happen because
-interpolated variable names may be enclosed in curly brackets, but this
-does not happen in normal code. For example, in C</${foo}bar/>, the
-content of the C<PPIx::Regexp::Token::Interpolation> object will be
-C<'${foo}'>, but the content of the C<PPI::Document> will be C<'$foo'>.
-
-=cut
-
-sub ppi {
+# Normalize the content of an interpolation object before making it into
+# a PPI document. The issue here is that things like ${x} are at least
+# warnings outside strings, but are normal inside them.
+sub __ppi_normalize_content {
     my ( $self ) = @_;
-    if ( exists $self->{ppi} ) {
-	return $self->{ppi};
-    } elsif ( exists $self->{content} ) {
-	( my $code = $self->{content} ) =~
-	    s/ \A ( [\@\$] ) [{] ( .* ) [}] \z /$1$2/smx;
-	return ( $self->{ppi} = PPI::Document->new(
-		\$code, readonly => 1 ) );
-    } else {
-	return;
-    }
+    my $content;
+    defined( $content = $self->content() )
+	or return $content;
+    # NOTE: perldata gives a regexp for this, but it requires Perl 5.10.
+    # I believe the following caputures the intent, except possibly for
+    # various weird combinations of '::' and "'".
+    $content =~
+	s/ \A
+	    ( \$ \# \$* | [\@\$] \$* )	# Sigil and possible casts
+	    [{] \s* (?: :: )* '?	# per perldata
+	    ( ^? (?: \w+ (?: (?: :: | ' ) \w+ )* (?: :: )? | [[:punct:]] ) )
+	    \s* [}] \z
+	/$1$2/smx;
+    return $content;
 }
 
-
 # Match the beginning of an interpolation.
 
 my $interp_re =
