@@ -43,7 +43,7 @@ use Carp qw{ confess };
 use List::Util qw{ first };
 use PPIx::Regexp::Constant qw{ @CARP_NOT };
 
-our $VERSION = '0.067';
+our $VERSION = '0.071';
 
 sub __new {
     my ( $class, $content, %arg ) = @_;
@@ -136,6 +136,16 @@ sub is_relative {
     return $self->{is_relative};
 }
 
+=head2 is_matcher
+
+This method returns a true value because, although we do not actually
+perform an analysis on the referred-to entity, we presume it matches
+something.
+
+=cut
+
+sub is_matcher { return 1; }
+
 =head2 name
 
  print "The name is ", $ref->name(), "\n";
@@ -187,7 +197,7 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -195,7 +205,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2019 by Thomas R. Wyant, III
+Copyright (C) 2009-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
